   //////////////////////////////////////////////////////////////////
  //                 Arduino 101 Benchmark                        //
 //       Get the latest version of the code here:               //
//              http://educ8s.tv/arduino-101                    //
/////////////////////////////////////////////////////////////////

#include <U8g2lib.h> // https://github.com/olikraus/u8g2

#define ITERATIONS 100000L    // number of iterations
#define REFRESH_TFT 2500      // refresh bar every 2500 iterations
#define ACTIVATED LOW 

int percent = 0;
int progress = 1;
const int buttonPin = 7;     
int buttonState = 0;    

#include <Wire.h>

U8G2_SSD1306_128X64_NONAME_F_SW_I2C u8g2(U8G2_R0, /* clock=*/ SCL, /* data=*/ SDA, /* reset=*/ U8X8_PIN_NONE);   // All Boards without Reset of the Display

void setup(void) {
  u8g2.begin();// Oled display begins
  pinMode(7, INPUT_PULLUP);  
  printUI();
}

void loop(void) {

  buttonState = digitalRead(7);
  if (buttonState == ACTIVATED) {
   
    clearScreen();
    drawBar();
    startCalculation();
  }

  delay(10);
}

void clearScreen()
{
  u8g2.clearBuffer();
  u8g2.setFont(u8g2_font_ncenB14_tr);
  u8g2.drawStr(8,15,"Benchmark");
  u8g2.sendBuffer();
}

void drawBar()
{
   u8g2.drawFrame(8,35,110,15);
   u8g2.sendBuffer();
}

void startCalculation()
{
  unsigned long start, time;
 unsigned long niter=ITERATIONS;
 int LEDcounter = 0;
 unsigned long i;
 float x = 1.0;
 float pi=1.0;

 Serial.begin(9600);
 Serial.print("Beginning ");
 Serial.print(niter);
 Serial.println(" iterations...");
 Serial.println();

 start = millis();  
 for ( i = 2; i < niter; i++) {
   x *= -1.0;
   pi += x / (2.0f*(float)i-1.0f);   
    if (LEDcounter++ > REFRESH_TFT) {
     LEDcounter = 0;
     progress++;
     percent = progress*100/(ITERATIONS/ REFRESH_TFT);
     fillBar(percent);
    }
 }
 time = millis() - start;
 
 pi = pi * 4.0;

 Serial.print("# of trials = ");
 Serial.println(niter);
 Serial.print("Estimate of pi = ");
 String piString = String(pi,7);
 String timeString = String(time)+"ms";
 Serial.println(piString);
 
 Serial.print("Time: "); Serial.print(time); Serial.println(" ms");
 clearScreen();
 printResults(piString,timeString);
 
}

void printUI()
{
  u8g2.clearBuffer();
  u8g2.setFont(u8g2_font_ncenB14_tr);
  u8g2.drawStr(8,15,"Benchmark");
  u8g2.drawStr(35,50,"START");
  u8g2.drawFrame(30,30,75,25);
  u8g2.sendBuffer();
}

void printResults(String pi, String time)
{
  u8g2.setFont(u8g2_font_ncenB12_tr);
  u8g2.setCursor(0, 35);
  u8g2.print("Pi: "+pi);
  u8g2.setCursor(0, 55);
  u8g2.print("Time: "+time+" ms");
  u8g2.sendBuffer();
}

void fillBar(int percent)
{
    int counter =35;
    percent = map(percent,0,100,8,109);     
    for(counter = 35; counter<50;counter++)
    {
     u8g2.drawHLine(8,counter,percent);
    }
    u8g2.sendBuffer();
}


